# Quick Start

> Running OpenHands Cloud or running on your own.

<Tabs>
  <Tab title="OpenHands Cloud">
    The easiest way to get started with OpenHands is on OpenHands Cloud, which comes with \$10 in free credits for new users.

    To get started with OpenHands Cloud, visit [app.all-hands.dev](https://app.all-hands.dev).

    For more information see [getting started with OpenHands Cloud.](/openhands/usage/cloud/openhands-cloud)
  </Tab>

  <Tab title="Running OpenHands on Your Own">
    Run OpenHands on your local system and bring your own LLM and API key.

    For more information see [running OpenHands on your own.](/openhands/usage/run-openhands/local-setup)
  </Tab>
</Tabs>


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt